@@ -1,12 +1,13 @@
 import sys
 from pathlib import Path
 from types import TracebackType
-from typing import List, Union, Tuple, Any
+from typing import List, Union, Tuple, Any, Callable
 import traceback
 import numpy as np
 import numpy.typing as npt
 
-from code_loader.contract.datasetclasses import SectionCallableInterface, PreprocessResponse
+from code_loader.contract.datasetclasses import SectionCallableInterface, PreprocessResponse, \
+    InstanceCallableInterface, ElementInstance
 
 
 def to_numpy_return_wrapper(encoder_function: SectionCallableInterface) -> SectionCallableInterface:
@@ -17,6 +18,15 @@ def to_numpy_return_wrapper(encoder_function: SectionCallableInterface) -> Secti
 
     return numpy_encoder_function
 
+def to_numpy_return_masks_wrapper(encoder_function: InstanceCallableInterface) -> InstanceCallableInterface:
+    def numpy_encoder_function(idx: Union[int, str], samples: PreprocessResponse, element_idx: int) -> Union[ElementInstance, None]:
+        result = encoder_function(idx, samples, element_idx)
+        if result is None:
+            return None
+        result.mask = np.array(result.mask)
+        return result
+    return numpy_encoder_function
+
 
 def get_root_traceback(exc_tb: TracebackType) -> TracebackType:
     return_traceback = exc_tb
